@@ -482,7 +482,7 @@ class RDoc::Store
     when :gem    then
       parent = File.expand_path '..', @path
       "gem #{File.basename parent}"
-    when :home   then '~/.rdoc'
+    when :home   then RDoc.home
     when :site   then 'ruby site'
     when :system then 'ruby core'
     else @path
@@ -557,7 +557,7 @@ class RDoc::Store
     #orig_enc = @encoding
 
     File.open cache_path, 'rb' do |io|
-      @cache = Marshal.load io.read
+      @cache = Marshal.load io
     end
 
     load_enc = @cache[:encoding]
@@ -616,7 +616,7 @@ class RDoc::Store
     file = class_file klass_name
 
     File.open file, 'rb' do |io|
-      Marshal.load io.read
+      Marshal.load io
     end
   rescue Errno::ENOENT => e
     error = MissingFileError.new(self, file, klass_name)
@@ -631,7 +631,7 @@ class RDoc::Store
     file = method_file klass_name, method_name
 
     File.open file, 'rb' do |io|
-      obj = Marshal.load io.read
+      obj = Marshal.load io
       obj.store = self
       obj.parent =
         find_class_or_module(klass_name) || load_class(klass_name) unless
@@ -651,7 +651,7 @@ class RDoc::Store
     file = page_file page_name
 
     File.open file, 'rb' do |io|
-      obj = Marshal.load io.read
+      obj = Marshal.load io
       obj.store = self
       obj
     end
@@ -723,7 +723,7 @@ class RDoc::Store
 
   def page name
     @text_files_hash.each_value.find do |file|
-      file.page_name == name
+      file.page_name == name or file.base_name == name
     end
   end
 
@@ -795,10 +795,8 @@ class RDoc::Store
 
     return if @dry_run
 
-    marshal = Marshal.dump @cache
-
     File.open cache_path, 'wb' do |io|
-      io.write marshal
+      Marshal.dump @cache, io
     end
   end
 
@@ -871,10 +869,8 @@ class RDoc::Store
 
     FileUtils.rm_f to_delete
 
-    marshal = Marshal.dump klass
-
     File.open path, 'wb' do |io|
-      io.write marshal
+      Marshal.dump klass, io
     end
   end
 
@@ -896,10 +892,8 @@ class RDoc::Store
 
     return if @dry_run
 
-    marshal = Marshal.dump method
-
     File.open method_file(full_name, method.full_name), 'wb' do |io|
-      io.write marshal
+      Marshal.dump method, io
     end
   end
 
@@ -918,10 +912,8 @@ class RDoc::Store
 
     return if @dry_run
 
-    marshal = Marshal.dump page
-
     File.open path, 'wb' do |io|
-      io.write marshal
+      Marshal.dump page, io
     end
   end
 
